@@ -1,4 +1,5 @@
-from appyter.fields import Field, PartialField
+from appyter.fields import Field
+from appyter.ext.dict import dict_collision_free_update
 
 class TabField(Field):
   ''' Representing a tab field which contains inner fields to choose from.
@@ -35,6 +36,12 @@ class TabField(Field):
       for field in fields:
         field['args']['parent'] = self.args['name']
 
+  def prepare(self, req):
+    data = super().prepare(req)
+    for value in self.value:
+      dict_collision_free_update(data, **value.prepare(req))
+    return data
+
   def constraint(self):
     if not self.raw_value:
       return not self.args.get('required')
